@@ -9,7 +9,7 @@ package Win32::Mutex;
 #
 #   Other modifications (c) 1997 by Gurusamy Sarathy <gsar@activestate.com>
 #
-# Author: Christopher J. Madsen <chris_madsen@geocities.com>
+# Author: Christopher J. Madsen <cjm@pobox.com>
 # Version: 1.00 (6-Feb-1998)
 #
 # This program is free software; you can redistribute it and/or modify
@@ -71,7 +71,8 @@ immediate ownership of the mutex (default false).  If C<$name> is
 omitted, creates an unnamed mutex object.
 
 If C<$name> signifies an existing mutex object, then C<$initial> is
-ignored and the object is opened.
+ignored and the object is opened.  If this happens, C<$^E> will be set
+to 183 (ERROR_ALREADY_EXISTS).
 
 =item $mutex = Win32::Mutex->open($name)
 
@@ -112,7 +113,7 @@ Use C<$MutObj-E<gt>release> instead.
 
 =head1 AUTHOR
 
-Christopher J. Madsen E<lt>F<chris_madsen@geocities.com>E<gt>
+Christopher J. Madsen E<lt>F<cjm@pobox.com>E<gt>
 
 Loosely based on the original module by ActiveWare Internet Corp.,
 F<http://www.ActiveWare.com>
